==> librenms-24.9.1v0.tgz: librenms/lang/zh-TW/sensors.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Sesnors Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to translate names and units of sensors
    |
    */

    'airflow' => [
        'short' => '氣流',
        'long' => '氣流',
        'unit' => 'cfm',
        'unit_long' => '每分鐘標準立方呎',
    ],
    'ber' => [
        'short' => 'BER',
        'long' => '位元錯誤率',
        'unit' => '',
        'unit_long' => '',
    ],
    'charge' => [
        'short' => '電量',
        'long' => '電量百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'chromatic_dispersion' => [
        'short' => '色散',
        'long' => '色散',
        'unit' => 'ps/nm/km',
        'unit_long' => 'Picoseconds per Nanometer per Kilometer',
    ],
    'cooling' => [
        'short' => 'Cooling',
        'long' => '',
        'unit' => 'W',
        'unit_long' => '瓦特',
    ],
    'count' => [
        'short' => 'Count',
        'long' => 'Count',
        'unit' => '',
        'unit_long' => '',
    ],
    'current' => [
        'short' => '電流',
        'long' => '電流',
        'unit' => 'A',
        'unit_long' => '安培',
    ],
    'dbm' => [
        'short' => 'dBm',
        'long' => 'dBm',
        'unit' => 'dBm',
        'unit_long' => '毫瓦分貝',
    ],
    'delay' => [
        'short' => '延遲',
        'long' => '延遲',
        'unit' => 's',
        'unit_long' => '秒',
    ],
    'eer' => [
        'short' => 'EER',
        'long' => '能效比',
        'unit' => '',
        'unit_long' => '',
    ],
    'fanspeed' => [
        'short' => '風扇轉速',
        'long' => '風扇轉速',
        'unit' => 'RPM',
        'unit_long' => '每分鐘旋轉次數',
    ],
    'frequency' => [
        'short' => '頻率',
        'long' => '頻率',
        'unit' => 'Hz',
        'unit_long' => '赫茲',
    ],
    'humidity' => [
        'short' => '濕度',
        'long' => '濕度百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'load' => [
        'short' => '負載',
        'long' => '負載百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'loss' => [
        'short' => '百分比',
        'long' => '遺失百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'power' => [
        'short' => '電力',
        'long' => '電力',
        'unit' => 'W',
        'unit_long' => '瓦特',
    ],
    'power_consumed' => [
        'short' => '消耗功率',
        'long' => '消耗功率',
        'unit' => 'kWh',
        'unit_long' => '千瓦小時',
    ],
    'power_factor' => [
        'short' => '功率因數',
        'long' => '功率因數',
        'unit' => '',
        'unit_long' => '',
    ],
    'pressure' => [
        'short' => '壓力',
        'long' => '壓力',
        'unit' => 'kPa',
        'unit_long' => '千帕',
    ],
    'quality_factor' => [
        'short' => '品質因子',
        'long' => '品質因子',
        'unit' => '',
        'unit_long' => '',
    ],
    'runtime' => [
        'short' => 'Runtime',
        'long' => 'Runtime',
        'unit' => '分',
        'unit_long' => '分鐘',
    ],
    'signal' => [
        'short' => '訊號',
        'long' => '訊號',
        'unit' => 'dBm',
        'unit_long' => '毫瓦分貝',
    ],
    'tv_signal' => [
        'short' => '訊號',
        'long' => 'TV 訊號',
        'unit' => 'dBmV',
        'unit_long' => '毫伏分貝',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => '訊號雜訊比',
        'unit' => 'dB',
        'unit_long' => '分貝',
    ],
    'state' => [
        'short' => '狀態',
        'long' => '狀態',
        'unit' => '',
    ],
    'temperature' => [
        'short' => '溫度',
        'long' => '溫度',
        'unit' => '°C',
        'unit_long' => '° 攝氏',
    ],
    'voltage' => [
        'short' => '電壓',
        'long' => '電壓',
        'unit' => 'V',
        'unit_long' => '伏特',
    ],
    'waterflow' => [
        'short' => '水流',
        'long' => '水流',
        'unit' => 'l/m',
        'unit_long' => '升每分鐘',
    ],
    'percent' => [
        'short' => '百分比',
        'long' => '百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
];

==> librenms-24.11.0v0.tgz: librenms/lang/zh-TW/sensors.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Sesnors Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are used to translate names and units of sensors
    |
    */

    'airflow' => [
        'short' => '氣流',
        'long' => '氣流',
        'unit' => 'cfm',
        'unit_long' => '每分鐘標準立方呎',
    ],
    'ber' => [
        'short' => 'BER',
        'long' => '位元錯誤率',
        'unit' => '',
        'unit_long' => '',
    ],
    'charge' => [
        'short' => '電量',
        'long' => '電量百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'chromatic_dispersion' => [
        'short' => '色散',
        'long' => '色散',
        'unit' => 'ps/nm',
        'unit_long' => 'Picoseconds per Nanometer',
    ],
    'cooling' => [
        'short' => 'Cooling',
        'long' => '',
        'unit' => 'W',
        'unit_long' => '瓦特',
    ],
    'count' => [
        'short' => 'Count',
        'long' => 'Count',
        'unit' => '',
        'unit_long' => '',
    ],
    'current' => [
        'short' => '電流',
        'long' => '電流',
        'unit' => 'A',
        'unit_long' => '安培',
    ],
    'dbm' => [
        'short' => 'dBm',
        'long' => 'dBm',
        'unit' => 'dBm',
        'unit_long' => '毫瓦分貝',
    ],
    'delay' => [
        'short' => '延遲',
        'long' => '延遲',
        'unit' => 's',
        'unit_long' => '秒',
    ],
    'eer' => [
        'short' => 'EER',
        'long' => '能效比',
        'unit' => '',
        'unit_long' => '',
    ],
    'fanspeed' => [
        'short' => '風扇轉速',
        'long' => '風扇轉速',
        'unit' => 'RPM',
        'unit_long' => '每分鐘旋轉次數',
    ],
    'frequency' => [
        'short' => '頻率',
        'long' => '頻率',
        'unit' => 'Hz',
        'unit_long' => '赫茲',
    ],
    'humidity' => [
        'short' => '濕度',
        'long' => '濕度百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'load' => [
        'short' => '負載',
        'long' => '負載百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'loss' => [
        'short' => '百分比',
        'long' => '遺失百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
    'power' => [
        'short' => '電力',
        'long' => '電力',
        'unit' => 'W',
        'unit_long' => '瓦特',
    ],
    'power_consumed' => [
        'short' => '消耗功率',
        'long' => '消耗功率',
        'unit' => 'kWh',
        'unit_long' => '千瓦小時',
    ],
    'power_factor' => [
        'short' => '功率因數',
        'long' => '功率因數',
        'unit' => '',
        'unit_long' => '',
    ],
    'pressure' => [
        'short' => '壓力',
        'long' => '壓力',
        'unit' => 'kPa',
        'unit_long' => '千帕',
    ],
    'quality_factor' => [
        'short' => '品質因子',
        'long' => '品質因子',
        'unit' => '',
        'unit_long' => '',
    ],
    'runtime' => [
        'short' => 'Runtime',
        'long' => 'Runtime',
        'unit' => '分',
        'unit_long' => '分鐘',
    ],
    'signal' => [
        'short' => '訊號',
        'long' => '訊號',
        'unit' => 'dBm',
        'unit_long' => '毫瓦分貝',
    ],
    'tv_signal' => [
        'short' => '訊號',
        'long' => 'TV 訊號',
        'unit' => 'dBmV',
        'unit_long' => '毫伏分貝',
    ],
    'snr' => [
        'short' => 'SNR',
        'long' => '訊號雜訊比',
        'unit' => 'dB',
        'unit_long' => '分貝',
    ],
    'state' => [
        'short' => '狀態',
        'long' => '狀態',
        'unit' => '',
    ],
    'temperature' => [
        'short' => '溫度',
        'long' => '溫度',
        'unit' => '°C',
        'unit_long' => '° 攝氏',
    ],
    'voltage' => [
        'short' => '電壓',
        'long' => '電壓',
        'unit' => 'V',
        'unit_long' => '伏特',
    ],
    'waterflow' => [
        'short' => '水流',
        'long' => '水流',
        'unit' => 'l/m',
        'unit_long' => '升每分鐘',
    ],
    'percent' => [
        'short' => '百分比',
        'long' => '百分比',
        'unit' => '%',
        'unit_long' => '百分比',
    ],
];
